<?php
//
// Copyright (c) 2008-2009 Nagios Enterprises, LLC.  All rights reserved.
//  
// $Id: suggest.php 59 2010-03-08 22:56:21Z egalstad $

require_once(dirname(__FILE__).'/includes/common.inc.php');

// start session
init_session();

// grab GET or POST variables 
grab_request_vars(false);

// check prereqs
check_prereqs();

// check authentication
check_authentication();

// handle request
route_request();



function route_request(){
	global $request;
	
	// make sure we have some query specified
	if(!isset($request['q']))
		exit();
	$query=$request['q'];

	if(isset($request['type']))
		$cmd=strtolower($request['type']);
	else
		$cmd="";

	//echo "Q: $query, TYPE: $cmd";
		
	switch($cmd){
	case "users":
		suggest_users($query);
		break;
	case "hosts":
		suggest_hosts($query);
		break;
	case "objects":
		suggest_objects($query);
		break;
	default:
		break;
		}

	exit();
	}

	
function suggest_users($query){
	global $request;

	$names=array();

	// back xml result from backend. if $query="egalstad", this fetches the following URL:
	//     http://dev1/nagiosreports/backend/?cmd=getusers&username=lks:egalstad

	// search on  username,(full)name, and email address
	
	// get usernames
	$searchstring="lks:".$query;
	$args=array(
		"cmd" => "getusers",
		"username" => $searchstring
		);
	$res1=get_backend_data($args);
	
	// get names
	$args=array(
		"cmd" => "getusers",
		"name" => $searchstring
		);
	$res2=get_backend_data($args);
	
	// get email addresses
	$args=array(
		"cmd" => "getusers",
		"email" => $searchstring
		);
	$res3=get_backend_data($args);
	
	// load the results into xml
	$xres1=simplexml_load_string($res1);
	$xres2=simplexml_load_string($res2);
	$xres3=simplexml_load_string($res3);
	
	// run an xpath query to only return the nodes we're interested in
	$xpres1=$xres1->xpath("/userlist/user/username");
	$xpres2=$xres2->xpath("/userlist/user/name");
	$xpres3=$xres3->xpath("/userlist/user/email");
		
	if($xres1){
		foreach($xres1->user  as $u){
			$names[]=strtolower($u->username);
			}
		}
	if($xres2){
		foreach($xres2->user  as $u){
			$names[]=strtolower($u->name);
			}
		}
	if($xres3){
		foreach($xres3->user  as $u){
			$names[]=strtolower($u->email);
			}
		}

	natcasesort($names);
	$names=array_flip(array_flip($names));
		
	foreach($names as $name)
		echo $name."|\n";
	}


function suggest_hosts($query){
	global $request;

	$names=array();
	
	// search on host name
	$args=array(
		"cmd" => "gethosts",
		"host_name" => "lks:".$query,
		"brevity" => 1,
		"is_active" => 1,
		);
	$res1=get_backend_data($args);

	$xres1=simplexml_load_string($res1);

	if($xres1){
		foreach($xres1->host  as $obj){
			$names[]=strtolower($obj->host_name);
			}
		}

	natcasesort($names);
	$names=array_flip(array_flip($names));
		
	foreach($names as $name)
		echo $name."|\n";
	}

function suggest_objects($query){
	global $request;

	$names=array();

	// search on both name and description
	
	// get name1 (name)
	$args=array(
		"cmd" => "getobjects",
		"name1" => "lks:".$query,
		"brevity" => 1,
		"is_active" => 1,
		);
	$res1=get_backend_data($args);

	// get name2 (description)
	$args=array(
		"cmd" => "getobjects",
		"name2" => "lks:".$query,
		"brevity" => 1,
		"is_active" => 1,
		);
	$res2=get_backend_data($args);

	$xres1=simplexml_load_string($res1);
	$xres2=simplexml_load_string($res2);

	if($xres1){
		foreach($xres1->object  as $obj){
			$names[]=strtolower($obj->name1);
			}
		}
	if($xres2){
		foreach($xres2->object  as $obj){
			$names[]=strtolower($obj->name2);
			}
		}

	natcasesort($names);
	$names=array_flip(array_flip($names));
		
	foreach($names as $name)
		echo $name."|\n";
	}


?>
